@@ -204,7 +204,12 @@ class Interpreter:
             data = fp.read(96)
             if b"\0" in data:
                 raise ValueError('cannot parse binary file')
-        parsed = cls.parse(str(data, 'utf-8'))
+        # make sure only first line is checkeed
+        data = str(data, 'utf-8').split('\n')[0]
+        if not data.startswith('#!'):
+            raise ValueError("doesn't look like a shebang: %s" % data)
+
+        parsed = cls.parse(data)
         if not parsed:
             raise ValueError("doesn't look like a shebang: %s" % data)
         for key, val in parsed.items():
@@ -426,6 +431,10 @@ class Interpreter:
         if not info:
             return
         info = info.groupdict()
+        if info['ver'] and (not version or version.minor is None):
+            # get version from soabi if version is not set of only major
+            # version number is set
+            version = Version("%s.%s" % (info['ver'][0], info['ver'][1]))
 
         if info['stableabi']:
             # files with stable ABI in name don't need changes
